-- Einfache Aggregate
SELECT c.CustomerID            AS Kunde,
       c.TerritoryID           AS Gebiet,
       YEAR(OrderDate)         AS Jahr,
       COUNT(soh.SalesOrderID) AS Bestellungen
  FROM Sales.Customer AS c INNER JOIN Sales.SalesOrderHeader AS soh
    ON c.CustomerID = soh.CustomerID
 GROUP BY c.CustomerID, c.TerritoryID, YEAR(OrderDate)
 ORDER BY Jahr, Gebiet, Bestellungen DESC

-- Ergebnis
/*
Kunde       Gebiet      Jahr        Bestellungen
----------- ----------- ----------- ------------
344         1           2001        2
218         1           2001        2
401         1           2001        2
73          1           2001        2
*/

-- Bildung von Aggregaten
SELECT c.CustomerID              AS Kunde,
       c.TerritoryID             AS Gebiet,
       YEAR(OrderDate)           AS Jahr,
       COUNT(soh.SalesOrderID)   AS [Best.]
  FROM Sales.Customer AS c INNER JOIN Sales.SalesOrderHeader AS soh
    ON c.CustomerID = soh.CustomerID
 WHERE c.TerritoryID <= 3
   AND YEAR(OrderDate) <= 2008
   AND c.CustomerID IN (11012, 11013)
 GROUP BY GROUPING SETS (c.CustomerID, c.TerritoryID, YEAR(OrderDate))
 ORDER BY Jahr, Gebiet, [Best.] DESC


-- Ergebnis
/*
Kunde       Gebiet      Jahr        Best.
----------- ----------- ----------- -----------
11012       NULL        NULL        2
11013       NULL        NULL        2
NULL        1           NULL        4
NULL        NULL        2007        2
NULL        NULL        2008        2
*/

-- Bildung von Dimensionen mit mehreren Feldern
SELECT c.CustomerID              AS Kunde,
       c.TerritoryID             AS Gebiet,
       YEAR(OrderDate)           AS Jahr,
       COUNT(soh.SalesOrderID)   AS [Best.]
  FROM Sales.Customer AS c INNER JOIN Sales.SalesOrderHeader AS soh
    ON c.CustomerID = soh.CustomerID
 WHERE c.TerritoryID <= 3
   AND YEAR(OrderDate) <= 2008
   AND c.CustomerID IN (11012, 11013)
 GROUP BY c.CustomerID, 
          GROUPING SETS (c.TerritoryID, 
                         YEAR(OrderDate),
                         (c.TerritoryID, YEAR(OrderDate)), 
						 ())
 ORDER BY Jahr, Gebiet, [Best.] DESC

 /*
 Kunde       Gebiet      Jahr        Best.
----------- ----------- ----------- -----------
11012       NULL        NULL        2
11013       NULL        NULL        2
11012       1           NULL        2
11013       1           NULL        2
11013       NULL        2007        1
11012       NULL        2007        1
11012       1           2007        1
11013       1           2007        1
11012       NULL        2008        1
11013       NULL        2008        1
11012       1           2008        1
11013       1           2008        1

(12 row(s) affected)
 */