-- Reihennummern ohne ROW_NUMBER()

-- Einfache Zhlung
SELECT SalesOrderID,
       TerritoryID,
       TotalDue,
       (SELECT COUNT(s2.SalesOrderID)
          FROM Sales.SalesOrderHeader AS s2
         WHERE s2.SalesOrderID <= s1.SalesOrderID) AS RN
  FROM Sales.SalesOrderHeader AS s1
WHERE s1.SalesOrderID < 43662

-- Ergebnis
/*
SalesOrderID TerritoryID TotalDue              RN
------------ ----------- --------------------- -----
43659        5           23153.2339            1
43660        5           1457.3288             2
43661        6           36865.8012            3
*/

-- Partitionierung
SELECT TerritoryID,
       YEAR(OrderDate) AS [Year],
       SUM(TotalDue)   AS Turnover,
       (SELECT COUNT(DISTINCT s2.TerritoryID)
          FROM Sales.SalesOrderHeader AS s2
         WHERE s2.TerritoryID <= s1.TerritoryID
           AND s2.TerritoryID BETWEEN 5 AND 7) AS RN
  FROM Sales.SalesOrderHeader AS s1
WHERE TerritoryID BETWEEN 5 AND 7
GROUP BY TerritoryID, YEAR(OrderDate)
ORDER BY YEAR(OrderDate), s1.TerritoryID

-- Ergebnis
/*
TerritoryID Year        Turnover              RN
----------- ----------- --------------------- -----------
5           2005        1632139.2545          1
6           2005        1866734.9221          2
7           2005        199531.723            3
5           2006        3179192.0926          1
6           2006        6130230.7354          2
7           2006        1535232.896           3
5           2007        2742200.428           1
6           2007        6964947.2034          2
7           2007        3815005.2509          3
5           2008        1330567.5918          1
6           2008        3437016.3271          2
7           2008        2569979.4761          3
*/