-- Umstze pro Jahr
SELECT YEAR(OrderDate) AS [Year],
       SUM(TotalDue)   AS Total
  FROM Sales.SalesOrderHeader
 GROUP BY YEAR(OrderDate)

-- Ergebnis
/*
Year        Total
----------- ---------------------
2007        47171489.546
2008        28888197.5082
2005        12693250.6264
2006        34463848.4353
*/

SELECT DISTINCT
  (SELECT SUM(TotalDue)
     FROM Sales.SalesOrderHeader
    WHERE Year(OrderDate) = 2007) AS [2007],
  (SELECT SUM(TotalDue)
     FROM Sales.SalesOrderHeader
    WHERE Year(OrderDate) = 2008) AS [200]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2007                  200
--------------------- ---------------------
47171489.546          28888197.5082
*/

SELECT CASE 
         WHEN YEAR(OrderDate) = 2007
         THEN SUM(TotalDue) ELSE NULL
       END AS [2007],
       CASE 
         WHEN YEAR(OrderDate) = 2008
         THEN SUM(TotalDue) ELSE NULL
       END AS [2008]
FROM Sales.SalesOrderHeader
GROUP BY YEAR(OrderDate)

-- Ergebnis
/*
2007                  2008
--------------------- ---------------------
47171489.546          NULL
NULL                  28888197.5082
NULL                  NULL
NULL                  NULL
(4 Zeile(n) betroffen)
*/

SELECT SUM(CASE YEAR(OrderDate)
            WHEN  2007 THEN TotalDue ELSE NULL
           END) AS [2007],
       SUM(CASE YEAR(OrderDate)
            WHEN 2008 THEN TotalDue ELSE NULL
           END) AS [2008]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2001                  2002
--------------------- ---------------------
14327552,2263         39875505,095
Warnung: Ein NULL-Wert wird durch einen Aggregat- oder sonstigen SET-Vorgang gelscht.
(1 Zeile(n) betroffen
*/

SELECT SUM(CASE 
            WHEN YEAR(OrderDate) = 2007
            THEN TotalDue ELSE NULL
           END) AS [2007],
       SUM(CASE 
            WHEN YEAR(OrderDate) = 2008
            THEN TotalDue ELSE NULL
           END) AS [2008],
       SUM(CASE 
             WHEN YEAR(OrderDate) > 2008
             THEN TotalDue ELSE NULL
           END) AS [2008 until today]
FROM Sales.SalesOrderHeader

-- Ergebnis
/*
2001                  2002                  2002 until today
--------------------- --------------------- ---------------------
14327552,2263         39875505,095          86504527,5033
Warnung: Ein NULL-Wert wird durch einen Aggregat- oder sonstigen SET-Vorgang gelscht.
(1 Zeile(n) betroffen)
*/